<?php

require_once __DIR__ . '/lib/Mobile_Detect.php';

elgg_register_event_handler('plugins_boot', 'system', 'pessek_chat_plugins_boot');

function pessek_chat_init() {
	
    	require_once(dirname(__FILE__) . '/lib/XmppPrebind2.php');
  	
	elgg_extend_view('elements/layout.css', 'theme/elements/topbar.css');

	//--trigger after user logged in	
    	elgg_register_event_handler('login:after', 'user', '\Pessek\PessekChat\PessekChatConfig::handleAfterLogin');  
	//-- trigger when account created by admin or self registration  
    	elgg_register_event_handler('create', 'user', '\Pessek\PessekChat\PessekChatConfig::adminOrSeftAccountCreation');
	//-- trigger when user account is deleted
	elgg_register_event_handler('delete', 'user', '\Pessek\PessekChat\PessekChatConfig::xmppUserDeleteByAdmin');

    	elgg_register_event_handler('create', 'relationship', '\Pessek\PessekChat\PessekChatConfig::friendshipAdd');
	elgg_register_event_handler('delete', 'relationship', '\Pessek\PessekChat\PessekChatConfig::friendshipDelete');
	elgg_register_event_handler('profileiconupdate', 'user', '\Pessek\PessekChat\PessekChatConfig::xmppAvatarUpdate');

	elgg_register_event_handler('profileupdate', 'user', '\Pessek\PessekChat\PessekChatConfig::xmppUserUpdate');
	elgg_register_event_handler('profileupdate', 'user', '\Pessek\PessekChat\PessekChatConfig::xmppUserUpdateByAdmin');

    	elgg_register_page_handler('chatusersettings', 'chatusersettings_page_handler');
    	elgg_register_page_handler('chatusersettingsprebind', 'chatusersettingsprebinds_page_handler');
	
	elgg_register_page_handler('pessek_chat', 'pessek_chat_page_handler');

  	elgg_register_plugin_hook_handler('usersettings:save', 'user', '\Pessek\PessekChat\PessekChatConfig::xmppHandleUserSettings');
    	elgg_register_plugin_hook_handler('elgg.data', 'page', '\Pessek\PessekChat\PessekChatConfig::pessekChatConfigUserPage');
    	elgg_register_plugin_hook_handler('elgg.data', 'site', '\Pessek\PessekChat\PessekChatConfig::pessekChatConfigUserSite');
	elgg_register_plugin_hook_handler('register', 'menu:site', ['\Pessek\PessekChat\ChatMenuHandler', 'siteMenu']);

	if (elgg_is_logged_in()) {

		$guid = elgg_get_logged_in_user_entity()->guid;
 		$user = get_user($guid);

		$user->chatViewMode = "overlayed";
		$detect = new \Pessek\PessekChat\Mobile_Detect();
		if ( $detect->isMobile() ) {
			$user->chatViewMode = "mobile";
		}

	}

	if (elgg_is_logged_in()) {

		$css_path = elgg_get_site_url() . "mod/pessek_chat/dist/";
		
		elgg_register_css("converse-min-css", $css_path . "converse.min.css");
		elgg_load_css('converse-min-css');

		elgg_define_js('converse-min', [
			'src' => 'mod/pessek_chat/dist/converse.min.js',
			'exports' => 'converse-min',
		]);
		elgg_define_js('emojis-js', [
			'src' => 'mod/pessek_chat/dist/emojis.js',
			'exports' => 'emojis-js',
		]);
		elgg_require_js('pessek_chat/converse.init.chat');
            

	}
	
}

function pessek_chat_plugins_boot() {
         
        elgg_register_event_handler('init', 'system', 'pessek_chat_init');
}

function pessek_chat_page_handler($page){
	//$page_type = elgg_extract(0, $page, 'fullscreen'); register_error($page_type);
	$page_type = $page[0];
	switch ($page_type) {
		case 'fullscreen':
			echo elgg_view_resource('pessek_chat/fullscreen');
			break;
		case 'migrate.php':
			echo elgg_view_resource('pessek_chat/migrate');
			break;
		default:
			echo elgg_view_resource('pessek_chat/fullscreen');
			break;
	}
}


function chatusersettings_page_handler(){

	$chat_domain = trim(elgg_get_plugin_setting('userxmppdomain', 'pessek_chat'));
    	$resources = "/resource";
    
    	$guid = elgg_get_logged_in_user_entity()->guid;
    	$user = get_user($guid);
    	$chat_username = $user->username;
    	$chat_password = base64_decode ($user->pessekchat_secret_key);
    
    	$chat_resources = $chat_username.'@'.$chat_domain.$resources;
    
    	$result = array(
                        'jid' => $chat_resources,
                        'password' =>$chat_password 
                    );
                    
    	echo json_encode($result);
    	return json_encode($result);
}

function chatusersettingsprebinds_page_handler(){
    /**
    * Comment here for explanation of the options.
    *
    * Create a new XMPP Object with the required params
    *
    * @param string $jabberHost Jabber Server Host
    * @param string $boshUri    Full URI to the http-bind
    * @param string $resource   Resource identifier
    * @param bool   $useSsl     Use SSL (not working yet, TODO)
    * @param bool   $debug      Enable debug
    * bosh port: https://ejabberd-esfam.auf.org:5280/http-bind/ 5280 and 5281 we have to enable bosh on both url (http and https and only http should be used for prebinding)
    */
    
    $chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
    $rand_val = substr( str_shuffle( $chars ), 0, 3 );
    
    $guid = elgg_get_logged_in_user_entity()->guid;
    $user = get_user($guid);
    $chat_username = $user->username;
    $chat_password =  base64_decode ($user->pessekchat_secret_key); 
    $resources = "resource".$chat_username.$rand_val.mt_rand(100,1000);
    $usergroup = elgg_echo('pessek_chat:settings:usergroup');
    
    $ejabberdip = trim(elgg_get_plugin_setting('ejabberdip', 'pessek_chat'));
    $xmlrpcport = trim(elgg_get_plugin_setting('xmlrpcport', 'pessek_chat'));
    $adminxmppdomain = trim(elgg_get_plugin_setting('adminxmppdomain', 'pessek_chat'));
    $adminxmppusername = trim(elgg_get_plugin_setting('adminxmppusername', 'pessek_chat'));
    $adminxmpppassword = trim(elgg_get_plugin_setting('adminxmpppassword', 'pessek_chat'));
    $userxmppdomain = trim(elgg_get_plugin_setting('userxmppdomain', 'pessek_chat'));
    $boshurl = trim(elgg_get_plugin_setting('boshurlhttp', 'pessek_chat'));
    
    $params = [
            "user" => $chat_username,
            "password" => $chat_password,
            "tld" => $userxmppdomain,
            "boshUrl" => $boshurl 
            //For openfire it's something like http://<your-xmpp-fqdn>:7070/http-bind/
        ];
        $xmpp = new XmppPrebind($params);
        echo json_encode($xmpp->connect()); //will return JID, SID, RID as JSON
}

